trackc - track view of chromosome conformation and multi-omics data
===================================================================

**trackc** is a Python Package to Flexible Visualization of 3D Genome and Multiomics.
It builds on top of `matplotlib`, from which it allow for flexible adjustments.


.. image:: https://raw.githubusercontent.com/seqyuan/trackc/main/docs/images/trackc_logo.png
    :alt: trackc title figure
    :width: 100px
    :align: center
    :target: https://doi.org/1xxxx.1358-2

Manuscript
----------
Please see our manuscript :cite:`Palla:22` in **Bioinformatics** to learn more.

Trackc's key applications
--------------------------
- Mark the abnormal interaction formed by the structural variation of the genome.
- Show the three-dimensional genome interaction and multi-omics data after rearrangement.
- Flexible and convenient layout for multi-track 

Getting started with trackc
----------------------------
- Browse :doc:`quick start </quick_start>`, :doc:`available tracks types </available_track_types>` and :doc:`gallary </gallary>`.
- Discuss usage on `discourse`_ and development on `github`_.

Contributing to trackc
-----------------------
We are happy about any contributions! Before you start, check out our `contributing guide`_.


.. toctree::
   :caption: General:
   :maxdepth: 1

   quick_start
   tutorials
   gallary
   api
   developer/index
   

.. _github: https://github.com/seqyuan/trackc



Citation
---------

Please cite trackc as follows:

Zan Yuan, Guoliang Li, Yang Chen.
**trackc: a Package for Flexible Visualization of rearrangement 3D Genome and Multi-omics**, Bioinformatics, Volume 48, Issue W1, 1 July 2023, Pages W177–W184, https://doi.org/10.1093/nar/gkaa220

